==> spacetraders-0.2.3.tar.gz: spacetraders-0.2.3/spacetraders/models/ship_cargo_item.py <==
from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    List,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
)

import attr
from pydantic import BaseModel, Field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ShipCargoItem")


class ShipCargoItem(BaseModel):
    """The type of cargo item and the number of units.

    Attributes:
        symbol (str): The unique identifier of the cargo item type.
        name (str): The name of the cargo item type.
        description (str): The description of the cargo item type.
        units (int): The number of units of the cargo item.
    """

    symbol: str = Field(alias="symbol")
    name: str = Field(alias="name")
    description: str = Field(alias="description")
    units: int = Field(alias="units")
    additional_properties: Dict[str, Any] = {}

    class Config:
        arbitrary_types_allowed = True
        allow_population_by_field_name = True

    def dict(self, *args, **kwargs):
        output = super().dict(*args, **kwargs)
        return {k: v for k, v in output.items() if v is not UNSET}

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> spacetraders-0.2.4.tar.gz: spacetraders-0.2.4/spacetraders/models/ship_cargo_item.py <==
from typing import (
    TYPE_CHECKING,
    Any,
    BinaryIO,
    Dict,
    List,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
)

import attr
from pydantic import BaseModel, Field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ShipCargoItem")


class ShipCargoItem(BaseModel):
    """The type of cargo item and the number of units.

    Attributes:
        symbol (str): The unique identifier of the cargo item type.
        name (str): The name of the cargo item type.
        description (str): The description of the cargo item type.
        units (int): The number of units of the cargo item.
    """

    symbol: str = Field(alias="symbol")
    name: str = Field(alias="name")
    description: str = Field(alias="description")
    units: int = Field(alias="units")
    additional_properties: Dict[str, Any] = {}

    class Config:
        arbitrary_types_allowed = True
        allow_population_by_field_name = True

    def dict(self, *args, **kwargs):
        output = super().dict(*args, **kwargs)
        return {k: v for k, v in output.items() if not isinstance(v, Unset)}

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
